@@ -1,6 +1,6 @@
 import gzip
 import json
-import os.path
+import mimetypes
 from urllib.parse import urljoin
 
 import requests
@@ -47,7 +47,7 @@ class Client:
             return self.request("PUT", key, data=f, **kwargs)
 
     def smart_put_object(self, key, data, content_type=None, headers={}, **kwargs):
-        if isinstance(dict, list):
+        if isinstance(data, (dict, list)):
             content_type = "application/json"
             data = json.dumps(data)
         if isinstance(data, str):
@@ -67,18 +67,7 @@ class Client:
 
 
 def guess_content_type(filename):
-    _, ext = os.path.splitext(filename)
-    if ext == "html":
-        return "text/html"
-    if ext == "js":
-        return "text/javascript"
-    if ext == "css":
-        return "text/css"
-    if ext == "png":
-        return "image/png"
-    if ext == "svg":
-        return "image/svg+xml"
-    if ext == "gif":
-        return "image/gif"
-    if ext in ["jpg", "jpeg"]:
-        return "image/jpeg"
+    content_type = mimetypes.guess_type(filename)[0]
+    if not content_type:
+        return "application/octet-stream"
+    return content_type
